@@ -217,7 +217,7 @@ init_guicontrol (struct basedata *base)
 	  { TAG_MUTEMOD,            "au_entry_mutekey",       NULL, th_modentry,   0},
 	  { TAG_SOUNDSYSTEM,        "au_label_soundsystem",   NULL, th_soundsystem,0},
 	  /* video / LCD */
-	  { TAG_LCDBRIGHTNESS,      "vi_itext_lcdbrightness", NULL, th_showvalue,  GCF_RONLY},
+	  { TAG_LCDBRIGHTNESS,      "vi_itext_lcdbrightness", NULL, th_showpvalue, GCF_RONLY},
 	  { TAG_LCDILLUMUPKEY,      "vi_entry_lcdbrightupkey",NULL, th_keyentry,   0},
 	  { TAG_LCDILLUMUPMOD,      "vi_entry_lcdbrightupkey",NULL, th_modentry,   0},
 	  { TAG_LCDILLUMDOWNKEY,    "vi_entry_lcdbrightdnkey",NULL, th_keyentry,   0},
@@ -225,7 +225,7 @@ init_guicontrol (struct basedata *base)
 	  { TAG_LCDFADINGSPEED,     "vi_spin_lcdfadespeed",   NULL, th_spinbutton, 0},
 	  { TAG_DIMFULLYDARK,       "vi_check_dimdark",       NULL, th_checkbox,   0},
 	  /* video / keyboard */
-	  { TAG_KBDBRIGHTNESS,      "vi_itext_kbdbrightness", NULL, th_showvalue,  GCF_RONLY},
+	  { TAG_KBDBRIGHTNESS,      "vi_itext_kbdbrightness", NULL, th_showpvalue, GCF_RONLY},
 	  { TAG_KBDILLUMUPKEY,      "vi_entry_kbdbrightupkey",NULL, th_keyentry,   0},
 	  { TAG_KBDILLUMUPMOD,      "vi_entry_kbdbrightupkey",NULL, th_modentry,   0},
 	  { TAG_KBDILLUMDOWNKEY,    "vi_entry_kbdbrightdnkey",NULL, th_keyentry,   0},
