@@ -93,7 +93,7 @@ timeout_callback (gpointer data)
 	struct tagitem *taglist;
 	int n;
 
-	struct pbbmessage *msg = (struct pbbmessage *) msgbuffer;
+	struct pbbmessage *msg = (struct pbbmessage *) ((void *) msgbuffer);
 
 	if (prgexit == 1) {
 		gtk_main_quit();
