@@ -25,7 +25,10 @@ int get_server_config(struct basedata *base);
 int set_server_config(struct basedata *base);
 int store_config_tag (struct basedata *base, long tag, long data);
 int garbage_collection (struct basedata *base);
+
+#ifdef HAVE_OLDLIBPBB     /* support for older libpbb.a */
 struct tagitem* find_tagitem (struct tagitem *taglist, long tag);
 int taglist_count (struct tagitem *taglist);
+#endif
 
 #endif    /* INCLUDE_MSGHANDLER_H */
