@@ -20,6 +20,7 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <string.h>
+#include <signal.h>
 #include <gtk/gtk.h>
 
 #include <pbb.h>
@@ -33,7 +34,7 @@
 #include "support.h"
 #include "init.h"
 
-volatile int prgexit = 0;
+volatile sig_atomic_t prgexit = 0;
 volatile struct basedata masterdata;
 
 int main(int argc, char *argv[])
@@ -44,17 +45,14 @@ int main(int argc, char *argv[])
 #ifdef ENABLE_NLS
 	setlocale(LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-//	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
+	gtk_init (&argc, &argv);
 	init_libpbb ();  /* initialise the libpbb library */
+	
 	if((rc = evaluate_args(argc, argv)) == 0) {		/* evaluate command line */
-#ifdef ENABLE_NLS
-		bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
-		gtk_set_locale ();
-		gtk_init (&argc, &argv);
 		add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE "/pixmaps");
 		add_pixmap_directory (PACKAGE_SOURCE_DIR "/pixmaps");
 		if ((rc = init_powerprefs (base)) == 0) {
